11.2.1. ModifiedArtisticLicense2.0 — setupjavax documentation

# 11.2.1. ModifiedArtisticLicense2.0

The modified Artistic License is based on the ArtisticLicense2.0, but adds the amendmend of “Forced-Fairplay-Constraints” for peer-to-peer fairplay rules. The modification is active in the cases:

- breach of the “Forced-Fairplay-Constraints”

- redistribution of the code in order to inherit the license and prevent breaches of the “Forced-Fairplay-Constraints” elsewise

The modification restricts, and even revokes the permission including the open source attribution in case of breaches. This is perfectly allright, as you may refer to cases like the faith of Andreas Pavel [AndreasPavel], or even my own - UnifiedSessionsManager (C) 2008 Arno-Can Uestuensoez [UnifiedSessionsManager].

It furthermore adds the non-revocable inheritance of the license for each reused part and contained parts in derived work, including concepts and design.

    License:ModifiedArtisticLicense2.0 = ArtisticLicense2.0 + Forced-Fairplay-Constraints
    From Ingenierubuero Arno-Can Uestuensoez
    Name    Modified Artistic License 2.0

License Part-I | ArtisicLicense2.0
License Part-II | Forced-Fairplay-Constraints

The ArtisticLicense2.0:

    License:ArtisticLicense2.0
    From Free Software Directory
    Name    Artistic License 2.0
    URL     http://www.perlfoundation.org/artistic_license_2_0

    License text

    Artistic License 2.0

    Copyright (c) 2000-2006, The Perl Foundation.

    Everyone is permitted to copy and distribute verbatim copies of this
    license document, but changing it is not allowed.  Preamble

    This license establishes the terms under which a given free software
    Package may be copied, modified, distributed, and/or
    redistributed. The intent is that the Copyright Holder maintains some
    artistic control over the development of that Package while still
    keeping the Package available as open source and free software.

    You are always permitted to make arrangements wholly outside of this
    license directly with the Copyright Holder of a given Package. If the
    terms of this license do not permit the full use that you propose to
    make of the Package, you should contact the Copyright Holder and seek
    a different licensing arrangement.  Definitions

    "Copyright Holder" means the individual(s) or organization(s) named in
    the copyright notice for the entire Package.

    "Contributor" means any party that has contributed code or other
    material to the Package, in accordance with the Copyright Holder's
    procedures.

    "You" and "your" means any person who would like to copy, distribute,
    or modify the Package.

    "Package" means the collection of files distributed by the Copyright
    Holder, and derivatives of that collection and/or of those files. A
    given Package may consist of either the Standard Version, or a
    Modified Version.

    "Distribute" means providing a copy of the Package or making it
    accessible to anyone else, or in the case of a company or
    organization, to others outside of your company or organization.

    "Distributor Fee" means any fee that you charge for Distributing this
    Package or providing support for this Package to another party. It
    does not mean licensing fees.

    "Standard Version" refers to the Package if it has not been modified,
    or has been modified only in ways explicitly requested by the
    Copyright Holder.

    "Modified Version" means the Package, if it has been changed, and such
    changes were not explicitly requested by the Copyright Holder.

    "Original License" means this Artistic License as Distributed with the
    Standard Version of the Package, in its current version or as it may
    be modified by The Perl Foundation in the future.

    "Source" form means the source code, documentation source, and
    configuration files for the Package.

    "Compiled" form means the compiled bytecode, object code, binary, or
    any other form resulting from mechanical transformation or translation
    of the Source form.  Permission for Use and Modification Without
    Distribution

    (1) You are permitted to use the Standard Version and create and use
    Modified Versions for any purpose without restriction, provided that
    you do not Distribute the Modified Version.  Permissions for
    Redistribution of the Standard Version

    (2) You may Distribute verbatim copies of the Source form of the
    Standard Version of this Package in any medium without restriction,
    either gratis or for a Distributor Fee, provided that you duplicate
    all of the original copyright notices and associated disclaimers. At
    your discretion, such verbatim copies may or may not include a
    Compiled form of the Package.

    (3) You may apply any bug fixes, portability changes, and other
    modifications made available from the Copyright Holder. The resulting
    Package will still be considered the Standard Version, and as such
    will be subject to the Original License.  Distribution of Modified
    Versions of the Package as Source

    (4) You may Distribute your Modified Version as Source (either gratis
    or for a Distributor Fee, and with or without a Compiled form of the
    Modified Version) provided that you cleanly document how it differs
    from the Standard Version, including, but not limited to, documenting
    any non-standard features, executables, or modules, and provided that
    you do at least ONE of the following:

    (a) make the Modified Version available to the Copyright Holder of the
    Standard Version, under the Original License, so that the Copyright
    Holder may include your modifications in the Standard Version.  (b)
    ensure that installation of your Modified Version does not prevent the
    user installing or running the Standard Version. In addition, the
    Modified Version must bear a name that is different from the name of
    the Standard Version.  (c) allow anyone who receives a copy of the
    Modified Version to make the Source form of the Modified Version
    available to others under (i) the Original License or (ii) a license
    that permits the licensee to freely copy, modify and redistribute the
    Modified Version using the same licensing terms that apply to the copy
    that the licensee received, and requires that the Source form of the
    Modified Version, and of any works derived from it, be made freely
    available in that license fees are prohibited but Distributor Fees are
    allowed.  Distribution of Compiled Forms of the Standard Version or
    Modified Versions without the Source

    (5) You may Distribute Compiled forms of the Standard Version without
    the Source, provided that you include complete instructions on how to
    get the Source of the Standard Version. Such instructions must be
    valid at the time of your distribution. If these instructions, at any
    time while you are carrying out such distribution, become invalid, you
    must provide new instructions on demand or cease further
    distribution. If you provide valid instructions or cease distribution
    within thirty days after you become aware that the instructions are
    invalid, then you do not forfeit any of your rights under this
    license.

    (6) You may Distribute a Modified Version in Compiled form without the
    Source, provided that you comply with Section 4 with respect to the
    Source of the Modified Version.  Aggregating or Linking the Package

    (7) You may aggregate the Package (either the Standard Version or
    Modified Version) with other packages and Distribute the resulting
    aggregation provided that you do not charge a licensing fee for the
    Package. Distributor Fees are permitted, and licensing fees for other
    components in the aggregation are permitted. The terms of this license
    apply to the use and Distribution of the Standard or Modified Versions
    as included in the aggregation.

    (8) You are permitted to link Modified and Standard Versions with
    other works, to embed the Package in a larger work of your own, or to
    build stand-alone binary or bytecode versions of applications that
    include the Package, and Distribute the result without restriction,
    provided the result does not expose a direct interface to the Package.
    Items That are Not Considered Part of a Modified Version

    (9) Works (including, but not limited to, modules and scripts) that
    merely extend or make use of the Package, do not, by themselves, cause
    the Package to be a Modified Version. In addition, such works are not
    considered parts of the Package itself, and are not subject to the
    terms of this license.  General Provisions

    (10) Any use, modification, and distribution of the Standard or
    Modified Versions is governed by this Artistic License. By using,
    modifying or distributing the Package, you accept this license. Do not
    use, modify, or distribute the Package, if you do not accept this
    license.

    (11) If your Modified Version has been derived from a Modified Version
    made by someone other than you, you are nevertheless required to
    ensure that your Modified Version complies with the requirements of
    this license.

    (12) This license does not grant you the right to use any trademark,
    service mark, tradename, or logo of the Copyright Holder.

    (13) This license includes the non-exclusive, worldwide,
    free-of-charge patent license to make, have made, use, offer to sell,
    sell, import and otherwise transfer the Package with respect to any
    patent claims licensable by the Copyright Holder that are necessarily
    infringed by the Package. If you institute patent litigation
    (including a cross-claim or counterclaim) against any party alleging
    that the Package constitutes direct or contributory patent
    infringement, then this Artistic License to you shall terminate on the
    date that such litigation is filed.

    (14) Disclaimer of Warranty: THE PACKAGE IS PROVIDED BY THE COPYRIGHT
    HOLDER AND CONTRIBUTORS "AS IS' AND WITHOUT ANY EXPRESS OR IMPLIED
    WARRANTIES. THE IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
    PARTICULAR PURPOSE, OR NON-INFRINGEMENT ARE DISCLAIMED TO THE EXTENT
    PERMITTED BY YOUR LOCAL LAW. UNLESS REQUIRED BY LAW, NO COPYRIGHT
    HOLDER OR CONTRIBUTOR WILL BE LIABLE FOR ANY DIRECT, INDIRECT,
    INCIDENTAL, OR CONSEQUENTIAL DAMAGES ARISING IN ANY WAY OUT OF THE USE
    OF THE PACKAGE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

    Permission is granted to copy, distribute and/or modify this document under the terms
    of the GNU Free Documentation License, Version 1.3 or any later version published by
    the Free Software Foundation; with no Invariant Sections, no Front-Cover Texts, and no
    Back-Cover Texts. A copy of the license is included in the page
    "GNU Free Documentation License".

    The copyright and license notices on this page only apply to the text on this page.
    Any software or copyright-licenses or other similar notices described in this text
    has its own copyright notice and license, which can usually be found in the distribution
    or license text itself.
    Retrieved from "http://directory.fsf.org/wiki?title=License:ArtisticLicense2.0&oldid=15486"
    Category:

        License

    The FSF is a charity with a worldwide mission to advance software freedom learn about
    our history and work.

    Copyright (C) 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015 Free Software Foundation, Inc.

    Licensed under the GNU Free Documentation License, version 1.3 or later.

    Copyright Infringement Notification

    The FSF also has sister organizations in France, Latin America, Europe and India.

The Forced-Fairplay-Constraints amendments, the modification of the ArtisticLicense2.0:

    INVARIANT_SECTION_BEG:The whole document

    Document Data:
    ==============

    ORIGINAL-AUTHOR: Arno-Can Uestuensoez - @Ingenieurbuero Arno-Can Uestuensoez

    TITLE: Forced-Fairplay-Constraints
    SUBTITLE: Enforcement of Fairplay for Opensource Licenses - Con-Trolls
    AUTHOR: Arno-Can Uestuensoez - @Ingenieurbuero Arno-Can Uestuensoez
    COPYRIGHT: [2007,2008,2010,2013,2014,2015, 2016] Arno-Can Uestuensoez
    VERSION: 00.00.009
    RELEASE: 00.00.009
    DATE: 2016-03-04
    UUID: 6fb5eecc-310c-4147-98e4-7a41698113f4
    SCOPE: This release replaces and obsoletes any previous version.

    THIS-DOCUMENT:
         LICENSE: CC-BY-ND-4.0 - The Craetive Commons

        Licensed under the above conditions, refer to contained documents
        or online:

          http://creativecommons.org/licenses/by-nd/4.0/

        Unless required by applicable law or agreed to in writing, software
        distributed under the License is distributed on an "AS IS" BASIS,
        WITHOUT WARRANTIES OF ANY KIND, either express or implied.
        See the License for the specific language governing permissions and
        limitations under the License.

    **OpenSource with enforcement of peer-to-peer fairness**
    ========================================================

    Still in general fully compliant OpenSource, but not for Trolls.

    The following restrictions are added to the assigned base-licenses
    as constraints under the following listed conditions by the original
    author Arno-Can Uestuensoez Copyright(C) 2007-2016.

    As a tribute to the obvious neccesity of the enforcement of
    peer-to-peer fairness the following constraints are included
    in any assigned license to the provided Software. These may in worst
    case withdraw the license from the licensee and the related group
    for lifetime, dating back to the beginning of use - which is
    considered as the public release.

    You are free to provide the parts of your own contribution by any
    license, as long as the original base remains in literal compliance
    to the linked base license(s) including this ammendment. The mandatory
    literal compliance of this license add-on in advance of the original
    author must be inherited on the derived conceptual and implementation
    parts into any derived work.

    This is due to the racking financial experience of the original
    author caused by the vast fraud and cheeting after the introduction
    of the Multi-Vendor CloudManagement System 'UnifiedSessionsManager'
    (C)2008-2016 @Ingenieurbuero Arno-Can Uestuensoez,
    https://sourceforge.net/projects/ctys/
    originally published under GPL-3/2008.

    So the license is and remains in case of fairplay open source, else
    is completely withdrawn for all the persons being part and/or related
    to the issue. Thus the OpenSource is still the right place to live
    for it.

       For recommendations on the commom fraud in conjunction with the
       misuse of skills profiles feel free to refer to:

          http://xkcd.com/1303/

       Ask to arrange a confirmation call within 2-3 business days. If
       they cannot ...for whatever reason..., forward me the evidence
       please. Record the confirmation call officially and store it
       please, I officially confirm to record my confirmation call only
       for anyone. I am going to blog each call openly on the internet
       for your confirmation. I also enumerate each application
       individually with a UUID, and sign this with a sha256/sha512 hash.
       These are included in any legal contact, else it is fraud!

       See the full story elsewhere...

    The following constraints are part of this license agreement, they
    additionally superpose in any case of inconsistency the terms in the
    previous defined licenses with highest priority:

    Unfair competition
    ==================

    In case of competition against the author for any bid, permissions
    based on or involved this work are rejected for any work related
    to the bid.

    In case unfair competion against the author, including cases not
    known to the author worldwide, this includes the forwarding of
    unauthorized data about the author into any kind of legal, and/or
    illegal network like procurement systems, in the past or from now on,
    all license permissions are rejected.

    The loss of license comprises all involved parties, including customers,
    subcontractors, and competitors as a whole, including chained, shifted,
    and nested ownership, responsibility, and/or involvement.

    Balanced duties and rights
    ==========================

    In case of a law suite or any legal action against the author, e.g.
    due to intellectual property, or any other, either direct, or indirect,
    any permitted license - to this parties, their subcontractors nested
    to the complete level, and any involved person - is rejected back to
    the beginning for concepts and code including derived works.

    Invariant Sections
    ==================

    The artefacts contain invariant sections, which comprise the
    information about the original author and the copyright. Changing these
    results in immediate drop of any permission including previous licenses.
    This is also the case for any change of any copyright statement from
    any deployment package or copied information.

    These sections are marked by the string

      INVARIANT_SECTION_BEG:...
      <project-information-and-data>
      INVARIANT_SECTION_END:...

    and could simply be find by common tools.

    Software Patents
    ================

    You agree that in particular in the case that any previous constraint
    has to be applied, the author is eventually going to apply his
    intellectual property rights arbitrarily and without the requirement of
    any previous notice. Either personally, or by transferring his rights
    to third parties.

    Remarks
    =======

    Any rejection caused by violation of the license conditions could be
    withdrawn personally by the original author(s) written statement
    explicitly only, which requires the proactive disclosure of the whole
    issue in an official written and signed statement by the potentially
    violating party.

    You have additionally to agree in any commercial issue to proof
    reversal for using this software and related concepts. With using this
    software you accept the authors choice of the country and court for
    cleaning any leagal issue.

    INVARIANT_SECTION_END:The whole document